==> openmtpk-0.5.4.tar.gz: openmtpk-0.5.4/include/ml.hpp <==
/**
 * @file
 *
 * @brief openMTPK MACHINE/DEEP LEARNING MODULE 
 * 
 * @details This file serves as the core header for the Machine & Deep 
 * Learning module. This header includes the following :
 *  - Regression
 *      * Linear
 *      * Logistic
 *      * Gausian
 *      * Polynomial
 *      * Lasso
 *      * Ridge
 *  - Classifiers
 *      * Bayes Classification
 *      * Nearest Neighbor
 *      * Decision Tree
 *      * Random Forest
 *      * Support Vector
 *  - Resampling
 *      * Cross-Validation
 *      * Bootstrap
 *      * Permutation Test
 *  - Neural Networks
 *      * Naive
 *      * Multi-layer Perceptron
 *      * Bayes
 *      * Kohonen (Self-Organizing Map)
 */
#ifndef ML_HPP
#define ML_HPP


/**
 * @brief \b Regression \b Algorithms
 * @details includes : 
 *  * Linear Regression
 *
 * @note Some cases of Regression are innately Classification algorithms
 * 
 * @todo 
 *  * logreg
 *  * gausreg 
 *  * polyreg
 *  * lassoreg
 *  * ridgereg
 */
#define REGRESSION
#include "ml/linreg.hpp"
// #include "ml/logreg.hpp"
// #include "ml/gausreg.hpp"
// #include "ml/polyreg.hpp"
// #include "ml/lassoreg.hpp"
// #include "ml/ridgereg.hpp"
/*****************************************************************************/

/**
 * @brief \b Classification \b Algorithms
 * @details includes : 
 *  * Bayes Classifier
 *  * Nearest Neighbor
 *
 * @note These algorithms are tightly coupled with Regression algorithms
 *
 * @todo 
 *  * Decision Tree
 *  * Random Forest 
 *  * Support Vector
 */
#define CLASSIFICATION
#include "ml/bayes_clf.hpp"
#include "ml/nearest_neighbor.hpp"
// #include "ml/decision_tree"
// #include "ml/rand_forest"
// #include "ml/support_vector"
/*****************************************************************************/

/**
 * @brief \b Resampling \b Techniques
 * @details includes : 
 *  * K-Fold Cross-Validation
 *
 * @todo 
 *  * Bootstrap 
 *  * Permutation Test
 */
#define RESAMPLING
#include "ml/k-foldCV.hpp"
// #include "ml/bootstrap.hpp"
// #include "ml/perm_test.hpp"

/*****************************************************************************/

/**
 * @brief \b Neural \b Networks 
 * @details includes : 
 *  * Naive Network
 *  * Bayes Network
 *  * Kohonen Network
 *  * Multi-Layer Perceptron
 */
#define NEURAL_NETWORKS
#include "ml/naive_network.hpp"
#include "ml/bayes_network.hpp"
#include "ml/kohonen_network.hpp"
#include "ml/mlp_network.hpp"
/*****************************************************************************/

#endif

==> openmtpk-0.6.2.tar.gz: openmtpk-0.6.2/include/ml.hpp <==
/**
 * @file
 *
 * @brief openMTPK MACHINE/DEEP LEARNING MODULE 
 * 
 * @details This file serves as the core header for the Machine & Deep 
 * Learning module. This header includes the following :
 *  - Regression
 *      * Linear
 *      * Logistic
 *      * Gausian
 *      * Polynomial
 *      * Lasso
 *      * Ridge
 *  - Classifiers
 *      * Bayes Classification
 *      * Nearest Neighbor
 *      * Decision Tree
 *      * Random Forest
 *      * Support Vector
 *  - Resampling
 *      * Cross-Validation
 *      * Bootstrap
 *      * Permutation Test
 *  - Neural Networks
 *      * Naive
 *      * Multi-layer Perceptron
 *      * Bayes
 *      * Kohonen (Self-Organizing Map)
 */
#ifndef ML_HPP
#define ML_HPP


/**
 * @brief \b Regression \b Algorithms
 * @details includes : 
 *  * Linear Regression
 *
 * @note Some cases of Regression are innately Classification algorithms
 * 
 * @todo 
 *  * logreg
 *  * gausreg 
 *  * polyreg
 *  * lassoreg
 *  * ridgereg
 */
#define REGRESSION
#include "ml/linreg.hpp"
// #include "ml/logreg.hpp"
// #include "ml/gausreg.hpp"
// #include "ml/polyreg.hpp"
// #include "ml/lassoreg.hpp"
// #include "ml/ridgereg.hpp"
/*****************************************************************************/

/**
 * @brief \b Classification \b Algorithms
 * @details includes : 
 *  * Bayes Classifier
 *  * Nearest Neighbor
 *
 * @note These algorithms are tightly coupled with Regression algorithms
 *
 * @todo 
 *  * Decision Tree
 *  * Random Forest 
 *  * Support Vector
 */
#define CLASSIFICATION
// #include "ml/bayes_clf.hpp"
// #include "ml/nearest_neighbor.hpp"
// #include "ml/decision_tree"
// #include "ml/rand_forest"
// #include "ml/support_vector"
/*****************************************************************************/

/**
 * @brief \b Resampling \b Techniques
 * @details includes : 
 *  * K-Fold Cross-Validation
 *
 * @todo 
 *  * Bootstrap 
 *  * Permutation Test
 */
#define RESAMPLING
// #include "ml/k-foldCV.hpp"
// #include "ml/bootstrap.hpp"
// #include "ml/perm_test.hpp"

/*****************************************************************************/

/**
 * @brief \b Neural \b Networks 
 * @details includes : 
 *  * Naive Network
 *  * Bayes Network
 *  * Kohonen Network
 *  * Multi-Layer Perceptron
 */
// #define NEURAL_NETWORKS
// #include "ml/naive_network.hpp"
// #include "ml/bayes_network.hpp"
// #include "ml/kohonen_network.hpp"
#include "ml/mlp_network.hpp"
/*****************************************************************************/

#endif
